import { Module } from '@nestjs/common';
import { ServeStaticModule } from '@nestjs/serve-static';
import { ThrottlerModule } from '@nestjs/throttler';
import { join } from 'path';
import { AppController } from './app.controller';
import { AppService } from './app.service';
import { CSRFMiddleware } from './middleware/csrf.middleware';
import { ApiModule } from './modules/api/api.module';
import { ConfigurationModule } from './modules/config/config.module';

import { JWTModule } from './modules/jwt/jwt.module';
import { StaticFrontEndModule } from './modules/static-front-end/static-front-end.module';
import { UtilityModule } from './modules/utility/utility.module';

@Module({
  imports: [
    ServeStaticModule.forRoot({
      rootPath: join(__dirname, '..', 'uploads'),
      serveRoot: '/uploads',
    }),
    ThrottlerModule.forRoot({
      ttl: 10,
      limit: 10,
    }),
    ConfigurationModule,
    UtilityModule,
    JWTModule,
    StaticFrontEndModule,
    ApiModule,
  ],
  controllers: [AppController],
  providers: [AppService, CSRFMiddleware],
})
export class AppModule {}
