import { MiddlewareConsumer, Module, NestModule } from '@nestjs/common';
import { AuthMiddleware } from 'src/middleware/auth.middleware';
import { CSRFMiddleware } from 'src/middleware/csrf.middleware';
import { FlashMiddleware } from 'src/middleware/flash.middleware';
import { UserMiddleware } from 'src/middleware/user.middleware';
import { UserTokenModule } from 'src/modules/objects/user-token/user-token.module';
import { UserModule } from 'src/modules/objects/user/user.module';
import { TwoFactorController } from './two-factor.controller';

@Module({
  imports: [UserModule, UserTokenModule],
  controllers: [TwoFactorController],
})
export class TwoFactorModule implements NestModule {
  configure(consumer: MiddlewareConsumer) {
    consumer
      .apply(CSRFMiddleware, UserMiddleware)
      .forRoutes(TwoFactorController);
    consumer.apply(AuthMiddleware).forRoutes('account/two-factor/activate');
    consumer.apply(FlashMiddleware).forRoutes('account/two-factor/activate');
  }
}
